==> apache-ignite-2.7.0-src.zip: apache-ignite-2.7.0-src/modules/web-console/backend/errors/index.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

'use strict';

// Fire me up!

const AppErrorException = require('./AppErrorException');
const IllegalArgumentException = require('./IllegalArgumentException');
const IllegalAccessError = require('./IllegalAccessError');
const DuplicateKeyException = require('./DuplicateKeyException');
const ServerErrorException = require('./ServerErrorException');
const MissingResourceException = require('./MissingResourceException');
const AuthFailedException = require('./AuthFailedException');

module.exports = {
    implements: 'errors',
    factory: () => ({
        AppErrorException,
        IllegalAccessError,
        IllegalArgumentException,
        DuplicateKeyException,
        ServerErrorException,
        MissingResourceException,
        AuthFailedException
    })
};

==> apache-ignite-2.8.0-src.zip: apache-ignite-2.8.0-src/modules/web-console/backend/errors/index.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

'use strict';

// Fire me up!

const AppErrorException = require('./AppErrorException');
const IllegalArgumentException = require('./IllegalArgumentException');
const IllegalAccessError = require('./IllegalAccessError');
const DuplicateKeyException = require('./DuplicateKeyException');
const ServerErrorException = require('./ServerErrorException');
const MissingConfirmRegistrationException = require('./MissingConfirmRegistrationException');
const MissingResourceException = require('./MissingResourceException');
const AuthFailedException = require('./AuthFailedException');

module.exports = {
    implements: 'errors',
    factory: () => ({
        AppErrorException,
        IllegalAccessError,
        IllegalArgumentException,
        DuplicateKeyException,
        ServerErrorException,
        MissingConfirmRegistrationException,
        MissingResourceException,
        AuthFailedException
    })
};
